@@ -125,6 +125,9 @@ class SharedBackendConf(SharedBackendConfUtils):
     def isInternalSecureConnectionsEnabled(self):
         return self._jconf.isInternalSecureConnectionsEnabled()
 
+    def isInsecureXGBoostAllowed(self):
+        return self._jconf.isInsecureXGBoostAllowed()
+
     def flowDir(self):
         return self._get_option(self._jconf.flowDir())
 
@@ -170,8 +173,12 @@ class SharedBackendConf(SharedBackendConfUtils):
     def verifySslCertificates(self):
         return self._jconf.verifySslCertificates()
 
+    def isKerberizedHiveEnabled(self):
+        return self._jconf.isKerberizedHiveEnabled()
+
     def isHiveSupportEnabled(self):
-        return self._jconf.isHiveSupportEnabled()
+        warnings.warn("The method 'isHiveSupportEnabled' is deprecated and will be removed in 3.32. Use 'isKerberizedHiveEnabled' instead!")
+        return self.isKerberizedHiveEnabled()
 
     def hiveHost(self):
         return self._get_option(self._jconf.hiveHost())
@@ -185,6 +192,9 @@ class SharedBackendConf(SharedBackendConfUtils):
     def hiveToken(self):
         return self._get_option(self._jconf.hiveToken())
 
+    def restApiTimeout(self):
+        return self._jconf.restApiTimeout()
+
     #
     # Setters
     #
@@ -369,6 +379,14 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setInternalSecureConnectionsDisabled()
         return self
 
+    def setInsecureXGBoostAllowed(self):
+        self._jconf.setInsecureXGBoostAllowed()
+        return self
+
+    def setInsecureXGBoostDenied(self):
+        self._jconf.setInsecureXGBoostDenied()
+        return self
+
     def setFlowDir(self, dir):
         self._jconf.setFlowDir(dir)
         return self
@@ -425,13 +443,21 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setVerifySslCertificates(verify)
         return self
 
+    def setKerberizedHiveEnabled(self):
+        self._jconf.setKerberizedHiveEnabled()
+        return self
+
     def setHiveSupportEnabled(self):
-        self._jconf.setHiveSupportEnabled()
+        warnings.warn("The method 'setHiveSupportEnabled' is deprecated and will be removed in 3.32. Use 'setKerberizedHiveEnabled' instead!")
+        return self.setKerberizedHiveEnabled()
+
+    def setKerberizedHiveDisabled(self):
+        self._jconf.setKerberizedHiveDisabled()
         return self
 
     def setHiveSupportDisabled(self):
-        self._jconf.setHiveSupportDisabled()
-        return self
+        warnings.warn("The method 'setHiveSupportDisabled' is deprecated and will be removed in 3.32. Use 'setKerberizedHiveDisabled' instead!")
+        return self.setKerberizedHiveDisabled()
 
     def setHiveHost(self, host):
         self._jconf.setHiveHost(host)
@@ -448,3 +474,7 @@ class SharedBackendConf(SharedBackendConfUtils):
     def setHiveToken(self, token):
         self._jconf.setHiveToken(token)
         return self
+
+    def setRestApiTimeout(self, timeout):
+        self._jconf.setRestApiTimeout(timeout)
+        return self
